==> skill-core-16.0.3-sources.jar: com/ptteng/common/skill/service/UserTeamRelationService.java <==
package com.ptteng.common.skill.service;

import java.util.List;
import java.util.Map;

import org.osoa.sca.annotations.Remotable;

import com.ptteng.common.skill.model.UserTeamRelation;
import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;
import com.ptteng.common.dao.BaseDaoService;

@Remotable
public interface UserTeamRelationService extends BaseDaoService {

	



   		   
		
		public Long insert(UserTeamRelation userTeamRelation)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public List<UserTeamRelation> insertList(List<UserTeamRelation> userTeamRelationList)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public boolean delete(Long id)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public boolean update(UserTeamRelation userTeamRelation)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public boolean updateList(List<UserTeamRelation> userTeamRelationList)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public UserTeamRelation getObjectById(Long id)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public List<UserTeamRelation> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException;
		  
    	
	


				
	
	
	
	/**
	 * 
	 * @param
	 * @return
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public List<Long> getUserTeamRelationIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException;

	/**
	 * 
	 * @param
	 * @return
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public Integer countUserTeamRelationIds() throws ServiceException, ServiceDaoException;
	

}

==> skill-core-30.0.0-sources.jar: com/ptteng/common/skill/service/UserTeamRelationService.java <==
package com.ptteng.common.skill.service;

import java.util.List;
import java.util.Map;

import org.osoa.sca.annotations.Remotable;

import com.ptteng.common.skill.model.UserTeamRelation;
import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;
import com.ptteng.common.dao.BaseDaoService;

@Remotable
public interface UserTeamRelationService extends BaseDaoService {

	



   		   
		
		public Long insert(UserTeamRelation userTeamRelation)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public List<UserTeamRelation> insertList(List<UserTeamRelation> userTeamRelationList)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public boolean delete(Long id)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public boolean update(UserTeamRelation userTeamRelation)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public boolean updateList(List<UserTeamRelation> userTeamRelationList)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public UserTeamRelation getObjectById(Long id)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public List<UserTeamRelation> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException;
		  
    	
	


			
			
	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public Integer  countUserTeamRelationIdsByUidOrderByCreateAt(Long uid)throws ServiceException, ServiceDaoException;
			
			
	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public Integer  countUserTeamRelationIdsByTidOrderByCreateAt(Long tid)throws ServiceException, ServiceDaoException;
			
			
	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public Integer  countUserTeamRelationIdsByTidAndUidOrderByCreateAt(Long tid, Long uid)throws ServiceException, ServiceDaoException;
					
			
	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public List<Long>  getUserTeamRelationIdsByUidOrderByCreateAt(Long uid, Integer start, Integer limit)throws ServiceException, ServiceDaoException;
			
			
	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public List<Long>  getUserTeamRelationIdsByTidOrderByCreateAt(Long tid, Integer start, Integer limit)throws ServiceException, ServiceDaoException;
			
			
	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public List<Long>  getUserTeamRelationIdsByTidAndUidOrderByCreateAt(Long tid, Long uid, Integer start, Integer limit)throws ServiceException, ServiceDaoException;
		
	
	
	
	/**
	 * 
	 * @param
	 * @return
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public List<Long> getUserTeamRelationIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException;

	/**
	 * 
	 * @param
	 * @return
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public Integer countUserTeamRelationIds() throws ServiceException, ServiceDaoException;
	

}
